#libraries
library(dplyr)
library(tidyr)
library(lme4)
library(sjPlot)

#create function for running LME models
fit_lmer <- function(data_frame, source, language) {
  formula_text <- "value ~ V1*V2 + V1*V3 + (1 | SUBID)" #model formula
  formula_obj <- as.formula(formula_text) #save as object
  
  filtered_data <- subset(data_frame, V4 == source & V5 == language) #model data
  
  m1 <- lmer(formula_obj, #use lmer function and add model formula
             control = lmerControl(optimizer = "bobyqa", calc.derivs = FALSE), #add model optimizer
             data = filtered_data) #add model data
  
  return(m1) #return model results
}

#run models through function using filtered data 
m1 <- fit_lmer(df, 'A', 'E')
m2 <- fit_lmer(df, 'A', 'S')
m3 <- fit_lmer(df, 'A', 'B')
m4 <- fit_lmer(df, 'SB', 'E')
m5 <- fit_lmer(df, 'SB', 'S')
m6 <- fit_lmer(df, 'SB', 'B')
m7 <- fit_lmer(df, 'E', 'E')
m8 <- fit_lmer(df, 'E', 'S')
m9 <- fit_lmer(df, 'L', 'E')
m10 <- fit_lmer(df, 'L', 'S')

#print model results
tab_model(m1, m2, m3, m4, m5, m6, m7, m8, m9, m10,
          show.r2 = T,
          digits = 3, 
          digits.re = 3, 
          digits.p = 3,
          show.p = T,
          p.style = "numeric",
          auto.label = T,
          file = "FileName.xls")